/*
  Name:    Photometer.ino
  Created: 01.06.2016
  Author:  Roman Schönfeld & Daniel Hausherr
*/

/***********************************************************************************************
  This work is licensed under a Creative Commons Attribution 4.0 International (CC BY 4.0) License.

  You are free to:

  Share — copy and redistribute the material in any medium or format
  Adapt — remix, transform, and build upon the material
  for any purpose, even commercially.

  The licensor cannot revoke these freedoms as long as you follow the license terms.

  Under the following terms:

  Attribution — You must give appropriate credit, provide a link to the license, and indicate if
  changes were made. You may do so in any reasonable manner, but not in any way that suggests
  the licensor endorses you or your use.

  No additional restrictions — You may not apply legal terms or technological measures that
  legally restrict others from doing anything the license permits.

  Credits:
  Laboratory for Physics and Illumination Technologies,
  University of Applied Sciences Southern Westfalia
  Germany

  Make Light! Support by the BMBF in the development of this device is gratefully acknowledged
***************************************************************************************************/
#include <Wire.h>
#include <TFT.h>

#include "Photometer.h"
#include "Sauron.h"
#include "Display.h"
#include "Interface.h"

void setup() {
  pinMode(_READY_PIN, INPUT);
  // Display Hintergrundbeleuchtung Pin
  pinMode(_BL, OUTPUT);
  // Display Helligkeit Anfangswert
  analogWrite(_BL, _TFT_BRIGHTNESS);
  // Display Reset Pin
  pinMode(_RES, OUTPUT);
  digitalWrite(_RES, _NRESET);

  // Initialisiere I2C Bus
  init_i2c();
  // Initialisiere Display
  init_tft();
  // Initialisiere Menustruktur
  init_menu();
}

void loop() {
  
  // *** Bestimmt die Position des Joysticks Y - Achse und führt die entsprechende Funktion aus **
  if ((uint16_t)analogRead(_Y_MOVE) < (MIN_THRESHOLD + HYSTERESIS)) {
    if ((uint16_t)analogRead(_Y_MOVE) < MIN_THRESHOLD) {
      navigation_menue((uint8_t)DOWN);
      delay(DELAY_LOOP_MIN);
    }
    else {
      navigation_menue((uint8_t)DOWN);
      delay(DELAY_LOOP_MAX);
    }
  }
  else if ((uint16_t)analogRead(_Y_MOVE) > (MAX_THRESHOLD - HYSTERESIS)) {
    if ((uint16_t)analogRead(_Y_MOVE) > MAX_THRESHOLD) {
      navigation_menue((uint8_t)UP);
      delay(DELAY_LOOP_MIN);
    }
    else {
      navigation_menue((uint8_t)UP);
      delay(DELAY_LOOP_MAX);
    }
  }
  
  // *** Bestimmt die Position des Joysticks X - Achse und führt die entsprechende Funktion aus **
  else {
    if ((uint16_t)analogRead(_X_MOVE) < (MIN_THRESHOLD + HYSTERESIS)) {
      navigation_menue((uint8_t)RIGHT);
      delay(DELAY_LOOP_MAX);
    }
    else if ((uint16_t)analogRead(_X_MOVE) > (MAX_THRESHOLD - HYSTERESIS)) {
      navigation_menue((uint8_t)LEFT);
      delay(DELAY_LOOP_MAX);
    }
  }
  //*************************************************************************************************/
}
